Welcome to PyMilvus's documentation!
====================================

Overview
========

PyMilvus is a python SDK for Milvus2.0 and is a recommended way to work with Milvus. This documentation covers
every thing you need to know about PyMilvus.

:doc:`install`
    Instructions on how to install PyMilvus.

:doc:`tutorial`
    A quick start to use PyMilvus.

:doc:`api/api`
    The complete API documentation.

:doc:`param`
    Index and relevant parameters.

:doc:`results`
    How to deal with search results.

:doc:`changes`
    Changes in the latest PyMilvus.

:doc:`contribute`
    Method of contribution, bug shooting and contribution guide.

:doc:`faq`
    Some questions that come up often.

:doc:`about`
    How this documentation is generated.


.. toctree::
   :hidden:
   :maxdepth: 8
   :caption: Table of Contents

   install
   tutorial
   api/api
   param
   results
   changes
   faq
   contribute
   about


